@@ -640,8 +640,11 @@ glob (pattern, flags, errfunc, pglob)
 	      int success;
 	      char *name;
 #   if defined HAVE_GETLOGIN_R || defined _LIBC
+#ifdef _SC_LOGIN_NAME_MAX
 	      size_t buflen = sysconf (_SC_LOGIN_NAME_MAX) + 1;
-
+#else
+              size_t buflen = 20;
+#endif
 	      if (buflen == 0)
 		/* `sysconf' does not support _SC_LOGIN_NAME_MAX.  Try
 		   a moderate value.  */
